@@ -49,7 +49,6 @@ import signal       # for init_worker
 from math import cos, copysign, pi
 
 ###### Local application imports ######
-from sfalmanac.lib.alma_ephem import magnitudes
 from sfalmanac.lib import config
 if config.MULTIpr:  # in multi-processing mode ...
     # ! DO NOT PLACE imports IN CONDITIONAL 'if'-STATEMENTS WHEN MULTI-PROCESSING !
@@ -371,11 +370,10 @@ def planetstab(Date, ts, spad):
                 tab = tab + line + lineterminator
                 h += 1
 
-        mag_v, mag_m, mag_j, mag_s = magnitudes(Date)   # magnitudes from Ephem
         RAc_v, Dc_v, mag_v = vdm_Venus(Date)
-        RAc_m, Dc_m = vdm_Mars(Date)
+        RAc_m, Dc_m, mag_m = vdm_Mars(Date)             # in Skyfield >= 1.40
         RAc_j, Dc_j, mag_j = vdm_Jupiter(Date)
-        RAc_s, Dc_s = vdm_Saturn(Date)
+        RAc_s, Dc_s, mag_s = vdm_Saturn(Date)           # in Skyfield >= 1.40
         tab = tab + r'''\hline
 \multicolumn{{2}}{{|c|}}{{\rule{{0pt}}{{2.4ex}}Mer.pass. {}}} & 
 \multicolumn{{2}}{{c|}}{{\(\nu\) {}$'$ \emph{{d}} {}$'$ m {}}} & 
@@ -505,11 +503,10 @@ def planetstabm(Date, ts, spad):
                 tab = tab + line
                 h += 1
 
-        mag_v, mag_m, mag_j, mag_s = magnitudes(Date)   # magnitudes from Ephem
         RAc_v, Dc_v, mag_v = vdm_Venus(Date)
-        RAc_m, Dc_m = vdm_Mars(Date)
+        RAc_m, Dc_m, mag_m = vdm_Mars(Date)             # in Skyfield >= 1.40
         RAc_j, Dc_j, mag_j = vdm_Jupiter(Date)
-        RAc_s, Dc_s = vdm_Saturn(Date)
+        RAc_s, Dc_s, mag_s = vdm_Saturn(Date)           # in Skyfield >= 1.40
         tab = tab + r'''\cmidrule{{1-2}} \cmidrule{{4-5}} \cmidrule{{7-8}} \cmidrule{{10-11}} \cmidrule{{13-14}}
 \multicolumn{{2}}{{c}}{{\footnotesize{{Mer.pass. {}}}}} && 
 \multicolumn{{2}}{{c}}{{\footnotesize{{\(\nu\){}$'$ \emph{{d}}{}$'$ m{}}}}} && 
@@ -1432,8 +1429,8 @@ def page1():
     Enno Rodegerdts (\textcolor{blue}{\textsf{https://sv-inua.net/}}) created the original Nautical Almanac 'daily pages' in Pyalmanac using Python 2 and LaTeX. After contacting him I obtained permission for its future enhancement and maintenance. Pyalmanac uses Ephem.\\[12pt]
     Meanwhile Brandon Rhodes was working on a far more sophisticated astronomical library, Skyfield. This was 'state of the art' and clearly surpassed the 'Jean Meeus'-based Pyephem/Ephem. Skyfield uses NASA's NAIF (Navigation and Ancillary Information Facility) SPICE algorithms. The results agree with those from the HORIZONS System (\textit{operated by NASA JPL (Jet Propulsion Laboratory) SSD (Solar System Dynamics) group, not by NAIF}). This in turn implies that celestial positions calculated by Skyfield agree with those generated by the United States Naval Observatory and their \textit{Astronomical Almanac} to within 0.0005 arcseconds (half a milliarcsecond).\\[12pt]
     Pyephem was then in 'maintenance mode'. Clearly Pyalmanac needed adaptation to use Skyfield, and thus SFalmanac was born. However its performance was poor regarding the calculation of 'events' such as: sunrise, sunset, moonrise, moonset, civil twilight start/end and nautical twilight start/end. An interim (faster) solution was required.\\[12pt]
-    Skyalmanac was the result: a hybrid application using Ephem to calculate 'events' and Skyfield for the rest. This was indeed much faster at the cost of poorer 'event' time data. It took a while to find a better solution: multiprocessing, which was built into SFalmanac. This now could compare to the execution times in Pyalmanac but with improved results.\\[12pt]    
-    New functionality was added to SFalmanac: lunar phase as a graphic; Lunar Distance tables and charts. The original Skyalmanac is deprecated and will soon be replaced with the latest SFalmanac code.
+    A hybrid application, originally named Skyalmanac, was developed using Ephem to calculate 'events' and Skyfield for the rest. This was indeed much faster at the cost of poorer 'event time' data. It took a while to find a better solution: multiprocessing, which was built into SFalmanac. This now could compare to the execution times in Pyalmanac but with improved data.\\[12pt]
+    New functionality was added to SFalmanac, e.g. lunar phase as a graphic; Lunar Distance tables and charts. The original Skyalmanac is deprecated and has now been replaced with the latest SFalmanac code, so Skyalmanac and SFalmanac are now identical apart from the name.
     Since April 2019 \textcolor{blue}{\textsf{http://thenauticalalmanac.com}} has been publishing Celestial Navigation related material with software provided here.
 \newpage'''
 
